from .mydb import MyDB

# 比赛
class FTMatch:
  def __init__(self,
    # 比赛周编码
    matchWeek,

    # 比赛时间
    matchTime,

    # 联赛
    league,

    # 主队
    homeTeam,

    # 客队
    awayTeam,

    # 胜平负
    wdl,

    # 胜平负(让)
    wdls,

    # 比分
    score,

    # 总进球
    points,

    # 半全场
    double
  ):
    self.matchWeek = matchWeek
    self.matchTime = matchTime
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.wdl = wdl
    self.wdls = wdls
    self.score = score
    self.points = points
    self.double = double

  def toString(self):
    return ";".join((
      self.matchWeek,
      self.matchTime,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.wdl,
      self.wdls,
      self.score,
      self.points,
      self.double
    ))
  
  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return
    
    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('football', 'match', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()

# 赔率
class FTPrice:
  def __init__(self,
    # 比赛ID
    matchId,

    # 比赛周编码
    matchWeek,

    # 比赛时间
    matchTime,

    # 联赛
    league,

    # 主队
    homeTeam,

    # 客队
    awayTeam,

    # 胜平负
    wdlOdds = None,

    # 胜平负(让) - [w, d, l, s]
    wdlsOdds = None,

    # 比分 - [w(13) + d(4) + l(13)]
    scoreResult = None,

    # 进球数 - [0, 1, 2, 3, 4, 5, 6, >6]
    pointsResult = None,

    # 半全场 - [w/w, w/d, w/l, d/w, d/d, d/l, l/w, l/d, l/l]
    doubleResult = None
  ):
    self.matchId = matchId
    self.matchWeek = matchWeek
    self.matchTime = matchTime
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.wdlOdds = wdlOdds
    self.wdlsOdds = wdlsOdds
    self.scoreResult = scoreResult
    self.pointsResult = pointsResult
    self.doubleResult = doubleResult

  def toString(self):
    return ";".join((
      self.matchId,
      self.matchWeek,
      self.matchTime,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.wdlOdds.toString(),
      self.wdlsOdds.toString(),
      self.scoreResult.toString(),
      self.pointsResult.toString(),
      self.doubleResult.toString()
    ))

  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return
    
    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('football', 'price', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()

# 胜平负
class WDLOdds:
  def __init__(self,
    # 胜
    win = None,
    
    # 平
    dead = None,
    
    # 负
    lose = None
  ):
    self.win = win
    self.dead = dead
    self.lose = lose

  def datas(self, datas = []):
    self.win = datas[0]
    self.dead = datas[1]
    self.lose = datas[2]

  def toString(self):
    return '|'.join((self.win, self.dead, self.lose))

# 胜平负(让)
class WDLSpreadOdds:
  def __init__(self,
    # 胜
    win = None,
    
    # 平
    dead = None,
    
    # 负
    lose = None,

    # 让球
    spread = None
  ):
    self.win = win
    self.dead = dead
    self.lose = lose
    self.spread = spread

  def datas(self, datas = []):
    self.win = datas[0]
    self.dead = datas[1]
    self.lose = datas[2]
    self.spread = datas[3]

  def toString(self):
    return '|'.join((self.win, self.dead, self.lose, self.spread))

# 比分
class ScoreResult:
  def __init__(self,
    w10 = None, # 胜 1-0
    w20 = None, # 胜 2-0
    w21 = None, # 胜 2-1
    w30 = None, # 胜 3-0
    w31 = None, # 胜 3-1
    w32 = None, # 胜 3-2
    w40 = None, # 胜 4-0
    w41 = None, # 胜 4-1
    w42 = None, # 胜 4-2
    w50 = None, # 胜 5-0
    w51 = None, # 胜 5-1
    w52 = None, # 胜 5-2
    w99 = None, # 胜 其他
    d00 = None, # 平 0-0
    d11 = None, # 平 1-1
    d22 = None, # 平 2-2
    d33 = None, # 平 3-3
    d99 = None, # 平 其他
    l01 = None, # 负 0-1
    l02 = None, # 负 0-2
    l12 = None, # 负 1-2
    l03 = None, # 负 0-3
    l13 = None, # 负 1-3
    l23 = None, # 负 2-3
    l04 = None, # 负 0-4
    l14 = None, # 负 1-4
    l24 = None, # 负 2-4
    l05 = None, # 负 0-5
    l15 = None, # 负 1-5
    l25 = None, # 负 2-5
    l99 = None # 负 其他
  ):
    self.w10 = w10
    self.w20 = w20
    self.w21 = w21
    self.w30 = w30
    self.w31 = w31
    self.w32 = w32
    self.w40 = w40
    self.w41 = w41
    self.w42 = w42
    self.w50 = w50
    self.w51 = w51
    self.w52 = w52
    self.w99 = w99
    self.d00 = d00
    self.d11 = d11
    self.d22 = d22
    self.d33 = d33
    self.d99 = d99
    self.l01 = l01
    self.l02 = l02
    self.l12 = l12
    self.l03 = l03
    self.l13 = l13
    self.l23 = l23
    self.l04 = l04
    self.l14 = l14
    self.l24 = l24
    self.l05 = l05
    self.l15 = l15
    self.l25 = l25
    self.l99 = l99

  def datas(self, datas = []):
    self.w10 = datas[0]
    self.w20 = datas[1]
    self.w21 = datas[2]
    self.w30 = datas[3]
    self.w31 = datas[4]
    self.w32 = datas[5]
    self.w40 = datas[6]
    self.w41 = datas[7]
    self.w42 = datas[8]
    self.w50 = datas[9]
    self.w51 = datas[10]
    self.w52 = datas[11]
    self.w99 = datas[12]
    self.d00 = datas[13]
    self.d11 = datas[14]
    self.d22 = datas[15]
    self.d33 = datas[16]
    self.d99 = datas[17]
    self.l01 = datas[18]
    self.l02 = datas[19]
    self.l12 = datas[20]
    self.l03 = datas[21]
    self.l13 = datas[22]
    self.l23 = datas[23]
    self.l04 = datas[24]
    self.l14 = datas[25]
    self.l24 = datas[26]
    self.l05 = datas[27]
    self.l15 = datas[28]
    self.l25 = datas[29]
    self.l99 = datas[30]

  def toString(self):
    return '|'.join((
      self.w10,
      self.w20,
      self.w21,
      self.w30,
      self.w31,
      self.w32,
      self.w40,
      self.w41,
      self.w42,
      self.w50,
      self.w51,
      self.w52,
      self.w99,
      self.d00,
      self.d11,
      self.d22,
      self.d33,
      self.d99,
      self.l01,
      self.l02,
      self.l12,
      self.l03,
      self.l13,
      self.l23,
      self.l04,
      self.l14,
      self.l24,
      self.l05,
      self.l15,
      self.l25,
      self.l99)
    )

# 进球数
class PointsResult:
  def __init__(self,
    # 总0球
    p0 = None,
    
    # 总1球
    p1 = None,
    
    # 总2球
    p2 = None,
    
    # 总3球
    p3 = None,
    
    # 总4球
    p4 = None,
    
    # 总5球
    p5 = None,
    
    # 总6球
    p6 = None,
    
    # 总>6球
    p99 = None
  ):
    self.p0 = p0
    self.p1 = p1
    self.p2 = p2
    self.p3 = p3
    self.p4 = p4
    self.p5 = p5
    self.p6 = p6
    self.p99 = p99

  def datas(self, datas = []):
    self.p0 = datas[0]
    self.p1 = datas[1]
    self.p2 = datas[2]
    self.p3 = datas[3]
    self.p4 = datas[4]
    self.p5 = datas[5]
    self.p6 = datas[6]
    self.p99 = datas[7]

  def toString(self):
    return '|'.join((
      self.p0,
      self.p1,
      self.p2,
      self.p3,
      self.p4,
      self.p5,
      self.p6,
      self.p99
    ))

# 半全场
class DoubleResult:
  def __init__(self,
    # 胜/胜
    ww = None,
    
    # 胜/平
    wd = None,
    
    # 胜/负
    wl = None,
    
    # 平/胜
    dw = None,
    
    # 平/平
    dd = None,
    
    # 平/负
    dl = None,
    
    # 负/胜
    lw = None,
    
    # 负/平
    ld = None,
    
    # 负/负
    ll = None
  ):
   self.ww = ww
   self.wd = wd
   self.wl = wl
   self.dw = dw
   self.dd = dd
   self.dl = dl
   self.lw = lw
   self.ld = ld
   self.ll = ll

  def datas(self, datas = []):
    self.ww = datas[0]
    self.wd = datas[1]
    self.wl = datas[2]
    self.dw = datas[3]
    self.dd = datas[4]
    self.dl = datas[5]
    self.lw = datas[6]
    self.ld = datas[7]
    self.ll = datas[8]

  def toString(self):
    return '|'.join((
      self.ww,
      self.wd,
      self.wl,
      self.dw,
      self.dd,
      self.dl,
      self.lw,
      self.ld,
      self.ll
    ))

# 结果
class FTResult:
  def __init__(self,
    # 比赛时间
    matchTime,

    # 周次
    matchWeek,

    # 联赛
    league,

    # 主队
    homeTeam,

    # 客队
    awayTeam,

    # 是否单固场次
    single,

    # 半场比分
    half,

    # 全程比分
    whole,

    # 状态
    status  
  ):
    self.matchTime = matchTime
    self.matchWeek = matchWeek
    self.league = league
    self.homeTeam = homeTeam
    self.awayTeam = awayTeam
    self.single = single
    self.half = half
    self.whole = whole
    self.status = status

  def toString(self):
    return ';'.join((
      self.matchTime,
      self.matchWeek,
      self.league,
      self.homeTeam,
      self.awayTeam,
      self.single,
      self.half,
      self.whole,
      self.status
    ))

  def persist(self):
    cursor = MyDB.getCursor()
    if cursor is None:
      return
    
    sql = "insert into ta_crawl_ball(ball_type, data_type, content) values('football', 'result', %s)"
    cursor.execute(sql, self.toString())
    MyDB.commit()
    cursor.close()
    